/*
 * Copyright (C) 2002-2003 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.scrap;

import org.jdom.Element;

import com.intellij.openapi.components.ProjectComponent;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.util.InvalidDataException;
import com.intellij.openapi.util.JDOMExternalizable;
import com.intellij.openapi.util.WriteExternalException;
import com.intellij.openapi.wm.ToolWindow;
import com.intellij.openapi.wm.ToolWindowAnchor;
import com.intellij.openapi.wm.ToolWindowManager;

import com.kiwisoft.utils.gui.IconManager;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.2 $, $Date: 2004/10/17 12:02:41 $
 */
public class ScrapPlugin implements ProjectComponent, JDOMExternalizable
{
	private Project project;
	private ToolWindow toolWindow;

	public static final String TOOL_WINDOW_ID = "KiwiScrap";

	public ScrapPlugin(Project project)
	{
		this.project = project;
	}

	public void projectOpened()
	{
		initToolWindow();
	}

	public void projectClosed()
	{
		unregisterToolWindow();
	}

	public void initComponent()
	{
	}

	public void disposeComponent()
	{
	}

	public String getComponentName()
	{
		return "KiwiScrap";
	}

	public void readExternal(Element element) throws InvalidDataException
	{
		try
		{
			ScrapConfig.getInstance(project).readExternal(element, project);
			Element scraps=element.getChild("scraps");
			if (scraps!=null) ScrapManager.getInstance(project).readExternal(scraps);
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}
	}

	public void writeExternal(Element element) throws WriteExternalException
	{
		try
		{
			ScrapConfig.getInstance(project).writeExternal(element, project);
			Element scraps=new Element("scraps");
			element.addContent(scraps);
			ScrapManager.getInstance(project).writeExternal(scraps);
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}
	}

	private void initToolWindow()
	{
		ToolWindowManager toolWindowManager = ToolWindowManager.getInstance(project);

		toolWindow = toolWindowManager.registerToolWindow(TOOL_WINDOW_ID, new MainPanel(project), ToolWindowAnchor.BOTTOM);
		toolWindow.setTitle("Scrap");
		toolWindow.setIcon(IconManager.getIcon(getClass().getClassLoader(), "icons/scrap.png"));
	}

	private void unregisterToolWindow()
	{
		ScrapConfig.closeInstance(project);
		ScrapManager.closeInstance(project);
		ToolWindowManager toolWindowManager = ToolWindowManager.getInstance(project);
		toolWindowManager.unregisterToolWindow(TOOL_WINDOW_ID);
	}
}